@@ -1,6 +1,6 @@
 package CHI::t::Bugs;
 BEGIN {
-  $CHI::t::Bugs::VERSION = '0.40';
+  $CHI::t::Bugs::VERSION = '0.41';
 }
 use strict;
 use warnings;
@@ -10,11 +10,12 @@ use base qw(CHI::Test::Class);
 
 # A place for testing obscure bug fixes. When possible, test will be named for RT ticket.
 
-sub test_48998 : Test(1) {
+sub test_48998 : Tests {
     my $cache = CHI->new( driver => 'Memory', global => 1 );
     $cache->set( 'a', 5 );
     $cache->set( 'b', 6 );
     eval { die "bleah" };
+    $DB::single = 1;
     cmp_deeply( $cache->get_multi_arrayref( [ 'a', 'b' ] ),
         [ 5, 6 ], "get_multi" );
 }
