@@ -1,31 +1,31 @@
 package CHI::t::Constants;
 BEGIN {
-  $CHI::t::Constants::VERSION = '0.40';
+  $CHI::t::Constants::VERSION = '0.41';
 }
 use strict;
 use warnings;
 use CHI::Test;
 use base qw(CHI::Test::Class);
 
-sub test_import : Test(4) {
+sub test_import : Tests {
     {
         package Foo;
 BEGIN {
-  $Foo::VERSION = '0.40';
+  $Foo::VERSION = '0.41';
 }
         use CHI::Constants qw(CHI_Meta_Namespace);
     }
     {
         package Bar;
 BEGIN {
-  $Bar::VERSION = '0.40';
+  $Bar::VERSION = '0.41';
 }
         use CHI::Constants qw(:all);
     }
     {
         package Baz;
 BEGIN {
-  $Baz::VERSION = '0.40';
+  $Baz::VERSION = '0.41';
 }
     }
     is( Foo::CHI_Meta_Namespace, '_CHI_METACACHE' );
