@@ -1,6 +1,6 @@
 package CHI::t::Driver::File::DepthZero;
 BEGIN {
-  $CHI::t::Driver::File::DepthZero::VERSION = '0.40';
+  $CHI::t::Driver::File::DepthZero::VERSION = '0.41';
 }
 use strict;
 use warnings;
@@ -19,7 +19,7 @@ sub new_cache_options {
     return ( $self->SUPER::new_cache_options(), depth => 0 );
 }
 
-sub test_default_depth : Test(2) {
+sub test_default_depth : Tests {
     my $self = shift;
 
     my $cache = $self->new_cache();
