@@ -1,6 +1,6 @@
 package CHI::t::Driver::Subcache;
 BEGIN {
-  $CHI::t::Driver::Subcache::VERSION = '0.40';
+  $CHI::t::Driver::Subcache::VERSION = '0.41';
 }
 use strict;
 use warnings;
@@ -21,15 +21,15 @@ sub set_standard_keys_and_values {
 
 # Skip these tests - the logging will be wrong
 #
-sub test_l1_cache : Tests(1) {
+sub test_l1_cache : Tests {
     ok(1);
 }
 
-sub test_mirror_cache : Tests(1) {
+sub test_mirror_cache : Tests {
     ok(1);
 }
 
-sub test_logging : Tests(1) {
+sub test_logging : Tests {
     ok(1);
 }
 
