@@ -1,6 +1,6 @@
 package CHI::t::GetError;
 BEGIN {
-  $CHI::t::GetError::VERSION = '0.40';
+  $CHI::t::GetError::VERSION = '0.41';
 }
 use strict;
 use warnings;
@@ -18,7 +18,7 @@ sub writeonly_cache {
     );
 }
 
-sub test_get_errors : Test(10) {
+sub test_get_errors : Tests {
     my ( $key, $value ) = ( 'medium', 'medium' );
 
     my $error_pattern =
