@@ -1,6 +1,6 @@
 package CHI::t::Initialize;
 BEGIN {
-  $CHI::t::Initialize::VERSION = '0.40';
+  $CHI::t::Initialize::VERSION = '0.41';
 }
 use strict;
 use warnings;
@@ -27,7 +27,7 @@ sub is_bad {
         sprintf( "died with params '%s'", dump_one_line( \@params ) ) );
 }
 
-sub test_driver_options : Test(7) {
+sub test_driver_options : Tests {
     my $cache;
     is_good( driver       => 'Memory',              global => 1 );
     is_good( driver       => 'File' );
