@@ -1,6 +1,6 @@
 package CHI::t::Util;
 BEGIN {
-  $CHI::t::Util::VERSION = '0.40';
+  $CHI::t::Util::VERSION = '0.41';
 }
 use strict;
 use warnings;
@@ -11,12 +11,12 @@ use List::MoreUtils qw(uniq);
 use base qw(CHI::Test::Class);
 
 # The inevitably lame unique_id test
-sub test_unique_id : Tests(1) {
+sub test_unique_id : Tests {
     my @ids = map { unique_id } ( 0 .. 9 );
     cmp_deeply( \@ids, [ uniq(@ids) ], 'generated ten unique ids' );
 }
 
-sub test_random_string : Tests(2) {
+sub test_random_string : Tests {
     my @strings = map { random_string(100) } ( 0 .. 2 );
     cmp_deeply(
         \@strings,
@@ -30,14 +30,14 @@ sub test_random_string : Tests(2) {
     );
 }
 
-sub test_non_common_constructor_params : Tests(1) {
+sub test_non_common_constructor_params : Tests {
     my $params =
       { map { ( $_, 1 ) } qw( foo expires_in bar baz on_get_error ) };
     my $non_common_params = CHI::Driver->non_common_constructor_params($params);
     cmp_deeply( $non_common_params, { map { ( $_, 1 ) } qw(foo bar baz) } );
 }
 
-sub test_parse_memory_size : Tests(5) {
+sub test_parse_memory_size : Tests {
     my %results = (
         '12345' => '12345',
         '50K'   => 50 * 1024,
